"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.layerSocketServer = exports.layer = void 0;
var MessageStorage = _interopRequireWildcard(require("@effect/cluster/MessageStorage"));
var ShardingConfig = _interopRequireWildcard(require("@effect/cluster/ShardingConfig"));
var ShardStorage = _interopRequireWildcard(require("@effect/cluster/ShardStorage"));
var SocketRunner = _interopRequireWildcard(require("@effect/cluster/SocketRunner"));
var SqlMessageStorage = _interopRequireWildcard(require("@effect/cluster/SqlMessageStorage"));
var SqlShardStorage = _interopRequireWildcard(require("@effect/cluster/SqlShardStorage"));
var RpcSerialization = _interopRequireWildcard(require("@effect/rpc/RpcSerialization"));
var Effect = _interopRequireWildcard(require("effect/Effect"));
var Layer = _interopRequireWildcard(require("effect/Layer"));
var Option = _interopRequireWildcard(require("effect/Option"));
var _NodeClusterSocketCommon = require("./NodeClusterSocketCommon.js");
var NodeSocketServer = _interopRequireWildcard(require("./NodeSocketServer.js"));
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function (e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != typeof e && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (const t in e) "default" !== t && {}.hasOwnProperty.call(e, t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, t)) && (i.get || i.set) ? o(f, t, i) : f[t] = e[t]); return f; })(e, t); }
/**
 * @since 1.0.0
 */

/**
 * @since 1.0.0
 * @category Layers
 */
const layerSocketServer = exports.layerSocketServer = /*#__PURE__*/Effect.gen(function* () {
  const config = yield* ShardingConfig.ShardingConfig;
  const listenAddress = config.runnerListenAddress.pipe(Option.orElse(() => config.runnerAddress));
  if (Option.isNone(listenAddress)) {
    return yield* Effect.dieMessage("layerSocketServer: ShardingConfig.runnerListenAddress is None");
  }
  return NodeSocketServer.layer(listenAddress.value);
}).pipe(Layer.unwrapEffect);
/**
 * @since 1.0.0
 * @category Layers
 */
const layer = options => {
  const layer = options?.clientOnly
  // client only
  ? Layer.provide(SocketRunner.layerClientOnly, _NodeClusterSocketCommon.layerClientProtocol)
  // with server
  : Layer.provide(SocketRunner.layer, [layerSocketServer, _NodeClusterSocketCommon.layerClientProtocol]);
  return layer.pipe(Layer.provideMerge(options?.storage === "sql" ? SqlMessageStorage.layer : MessageStorage.layerNoop), Layer.provide(options?.storage === "sql" ? options.clientOnly ? Layer.empty : SqlShardStorage.layer : ShardStorage.layerNoop), Layer.provide(ShardingConfig.layerFromEnv(options?.shardingConfig)), Layer.provide(options?.serialization === "ndjson" ? RpcSerialization.layerNdjson : RpcSerialization.layerMsgPack));
};
exports.layer = layer;
//# sourceMappingURL=NodeClusterRunnerSocket.js.map